=============================
Using Neo in a library or app
=============================

.. Neo as a common layer for interoperability

.. figure showing Neo ecosystem

.. dependability - stable, community development, link to governance, continuous integration, testing library

.. low-level data reading - the RawIO layer (see rawio.rst)
